/*  Sesame - Storage and Querying architecture for RDF and RDF Schema
 *  Copyright (C) 2001-2006 Aduna
 *
 *  Contact: 
 *  	Aduna
 *  	Prinses Julianaplein 14 b
 *  	3817 CS Amersfoort
 *  	The Netherlands
 *  	tel. +33 (0)33 465 99 87
 *  	fax. +33 (0)33 465 99 87
 *
 *  	http://aduna-software.com/
 *  	http://www.openrdf.org/
 *  
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.openrdf.model;

import java.io.Serializable;

/**
 * An RDF statement.
 **/
public interface Statement extends Comparable, Serializable {

	/**
	 * Gets the subject of this statement.
	 *
	 * @return The statement's subject.
	 **/
	public Resource getSubject();

	/**
	 * Gets the predicate of this statement.
	 *
	 * @return The statement's predicate.
	 **/
	public URI getPredicate();

	/**
	 * Gets the object of this statement.
	 *
	 * @return The statement's object.
	 **/
	public Value getObject();

	/**
	 * Compares a statement object to another object.
	 * 
	 * @param other The object to compare this statement to.
	 * @return <tt>true</tt> if the other object is an instance of
	 * {@link Statement} and if their subjects, predicates and objects are
	 * equal.
	 */
	public boolean equals(Object other);
	
	/**
	 * The hash code of a statement is defined as follows:
	 * <pre>
	 * (0xFF0000 & subject.hashCode()) |
	 * (0x00FF00 & predicate.hashCode()) |
	 * (0x0000FF & object.hashCode());
	 * </pre>
	 * 
	 * @return A hash code for the statement.
	 */
	public int hashCode();
}
